all messages for Emacs-related lists mirrored at yhetil.org
 help / color / mirror / code / Atom feed
From: "Ville Skyttä" <ville.skytta@xemacs.org>
Subject: tcl.el typo fixes
Date: 28 Mar 2002 17:55:41 +0200	[thread overview]
Message-ID: <1017330941.3707.20.camel@bobcat.ods.org> (raw)

[-- Attachment #1: Type: text/plain, Size: 99 bytes --]

Hello,

here's a couple of typo fixes for tcl.el.

-- 
Ville Skyttä
ville.skytta@xemacs.org

[-- Attachment #2: tcl-typos.patch --]
[-- Type: text/plain, Size: 1230 bytes --]

--- tcl.el.1.66	Thu Mar 28 17:41:42 2002
+++ tcl.el	Thu Mar 28 17:44:39 2002
@@ -76,7 +76,7 @@
 ;;   middle of a defun, or between defuns.  should notice if point is
 ;;   on first line of defun (or maybe even in comments before defun).
 ;; * Allow continuation lines to be indented under the first argument
 ;;   of the preceeding line, like this:
 ;;      [list something \
 ;;            something-else]
 ;; * There is a request that indentation work like this:
@@ -988,7 +988,7 @@
 ;;
 
 (defun tcl-imenu-create-index-function ()
-  "Generate alist of indices for imenu."
+  "Generate alist of indices for `imenu'."
   (let ((re (concat tcl-proc-regexp "\\([^ \t\n{]+\\)"))
 	alist prev-pos)
     (goto-char (point-min))
@@ -1189,7 +1189,7 @@
   "Return t if point is just after the `#' beginning a real comment.
 Does not check to see if previous char is actually `#'.
 A real comment is either at the beginning of the buffer,
-preceeded only by whitespace on the line, or has a preceeding
+preceded only by whitespace on the line, or has a preceding
 semicolon, opening brace, or opening bracket on the same line."
   (save-excursion
     (backward-char)
@@ -76,7 +76,7 @@
 ;;   on first line of defun (or maybe even in comments before defun).
 ;; * Allow continuation lines to be indented under the first argument
-;;   of the preceeding line, like this:
+;;   of the preceding line, like this:
 ;;      [list something \
 ;;            something-else]

                 reply	other threads:[~2002-03-28 15:55 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1017330941.3707.20.camel@bobcat.ods.org \
    --to=ville.skytta@xemacs.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this external index

	https://git.savannah.gnu.org/cgit/emacs.git
	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.